package com.codigoparallevar.minicards.bridge.blocks;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.content.Context;

import androidx.core.app.NotificationCompat;

import com.codigoparallevar.minicards.R;
import com.codigoparallevar.minicards.bridge.ProgramakerBridgeService;

import java.util.Collections;
import java.util.LinkedList;
import java.util.List;
import java.util.Random;

public class DefaultAndroidBlocks {

    public static BridgeBlockListBuilder GetBuilder(Context ctx) {
        // System services
        String notifServiceId = Context.NOTIFICATION_SERVICE;
        NotificationManager notificationManager = (NotificationManager) ctx.getSystemService(notifServiceId);
        assert notificationManager != null;

        Random notificationRandom = new Random();

        String notificationChannelId = ProgramakerBridgeService.BridgeUserNotificationChannel;
        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.O) {
            NotificationChannel channel = new NotificationChannel(
                    ProgramakerBridgeService.BridgeUserNotificationChannel,
                    ProgramakerBridgeService.BridgeUserNotificationChannelName,
                    NotificationManager.IMPORTANCE_DEFAULT);
            notificationManager.createNotificationChannel(channel);
        }


        return new BridgeBlockListBuilder()
                // Notifications
                .addOperation(
                        "notifications_new",
                        "Create notification. Title: %1, text: %2",
                        new LinkedList<BlockArgumentDefinition>() {{
                            add(new BlockArgumentDefinition(BlockArgumentDefinition.Type.STRING, "My notification"));
                            add(new BlockArgumentDefinition(BlockArgumentDefinition.Type.STRING, "Sample description"));
                        }},
                        (List<?> params) -> {
                            if (params.size() != 2) {
                                throw new Exception("Expected two (2) arguments, found " + params.size());
                            }
                            String title = params.get(0).toString();
                            String description = params.get(1).toString();

                            Notification notif = new NotificationCompat
                                    .Builder(ctx, ProgramakerBridgeService.BridgeUserNotificationChannel)
                                    .setContentTitle(title)
                                    .setContentText(description)
                                    .setSmallIcon(R.drawable.ic_center_focus_weak_black) // TODO: Change icon
                                    .setPriority(NotificationCompat.PRIORITY_DEFAULT)
                                    .build();

                            int notificationId = notificationRandom.nextInt();
                            notificationManager.notify(notificationId, notif);
                        }
                )
                .addOperation(
                        "notifications_clear",
                        "Clear notifications",
                        Collections.emptyList(),
                        (List<?> params) -> {
                            notificationManager.cancelAll();
                        }
                );
    }
}
