package com.codigoparallevar.minicards.bridge.blocks;

import android.util.Log;

import com.codigoparallevar.minicards.types.functional.Consumer;
import com.programaker.bridge.ProgramakerBridgeConfigurationBlock;

import org.jetbrains.annotations.NotNull;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.List;

class OperationBlockDefinition implements ProgramakerBridgeConfigurationBlock {
    private final static String LogTag = "PM OpBlockDefinition";

    private final String id;
    private final String message;
    private final List<BlockArgumentDefinition> args;
    private final Consumer<List<?>> operation;

    public OperationBlockDefinition(String id, String message, List<BlockArgumentDefinition> args, Consumer<List<? extends Object>> operation) {
        this.id = id;
        this.message = message;
        this.args = args;
        this.operation = operation;
    }

    @NotNull
    @Override
    public JSONObject serialize() {
        JSONObject obj = new JSONObject();

        try {
            JSONArray arguments = new JSONArray();
            for (BlockArgumentDefinition arg : this.args) {
                arguments.put(arg.serialize());
            }

            obj.put("id", this.id);
            obj.put("function_name", this.id);
            obj.put("message", this.message);
            obj.put("block_type", "operation");
            obj.put("block_result_type", JSONObject.NULL);
            obj.put("arguments", arguments);
            obj.put("save_to",  JSONObject.NULL);
        } catch (JSONException ex) {
            Log.e(LogTag, "Error serializing block definition: " + ex, ex);
        }

        return obj;
    }

    @NotNull
    @Override
    public String getFunctionName() {
        return this.id;
    }

    @Override
    public void call(@NotNull List<?> arguments) throws Exception {
        this.operation.apply(arguments);
    }
}
