package com.codigoparallevar.minicards.parts.connectors;

import com.codigoparallevar.minicards.parts.style.CardTheme;

public class ConnectorTypeInfo {
    private final Type _type;

    public static ConnectorTypeInfo FromTypeName(String type) {
        if (type == null) {
            return new ConnectorTypeInfo(Type.UNKNOWN);
        }

        type = type.toLowerCase();
        if (type.equals("string")) {
            return new ConnectorTypeInfo(Type.STRING);
        }
        else if (type.equals("integer")) {
            return new ConnectorTypeInfo(Type.INTEGER);
        }
        else if (type.equals("float")) {
            return new ConnectorTypeInfo(Type.FLOAT);
        }
        else if (type.equals("boolean")) {
            return new ConnectorTypeInfo(Type.BOOLEAN);
        }
        else if (type.equals("pulse")) {
            return new ConnectorTypeInfo(Type.PULSE);
        }
        else if (type.equals("enum")) {
            return new ConnectorTypeInfo(Type.ENUM);
        }
        else if (type.equals("any")) {
            return new ConnectorTypeInfo(Type.ANY);
        }
        else {
            return new ConnectorTypeInfo(Type.UNKNOWN);
        }
    }

    public int getOuterColor() {
        switch (_type) {
            case ANY:
                return CardTheme.ANY_CONNECTOR_COLOR_OUTER;
            case ENUM:
                return CardTheme.ENUM_CONNECTOR_COLOR_OUTER;
            case FLOAT:
                return CardTheme.FLOAT_CONNECTOR_COLOR_OUTER;
            case PULSE:
                return CardTheme.PULSE_CONNECTOR_COLOR_OUTER;
            case STRING:
                return CardTheme.STRING_CONNECTOR_COLOR_OUTER;
            case BOOLEAN:
                return CardTheme.BOOLEAN_CONNECTOR_COLOR_OUTER;
            case INTEGER:
                return CardTheme.INTEGER_CONNECTOR_COLOR_OUTER;
            case UNKNOWN:
                return CardTheme.UNKNOWN_CONNECTOR_COLOR_OUTER;
            default:
                return CardTheme.UNKNOWN_CONNECTOR_COLOR_OUTER;
        }
    }


    public int getInnerColor() {
        switch (_type) {
            case ANY:
                return CardTheme.ANY_CONNECTOR_COLOR_INNER;
            case ENUM:
                return CardTheme.ENUM_CONNECTOR_COLOR_INNER;
            case FLOAT:
                return CardTheme.FLOAT_CONNECTOR_COLOR_INNER;
            case PULSE:
                return CardTheme.PULSE_CONNECTOR_COLOR_INNER;
            case STRING:
                return CardTheme.STRING_CONNECTOR_COLOR_INNER;
            case BOOLEAN:
                return CardTheme.BOOLEAN_CONNECTOR_COLOR_INNER;
            case INTEGER:
                return CardTheme.INTEGER_CONNECTOR_COLOR_INNER;
            case UNKNOWN:
                return CardTheme.UNKNOWN_CONNECTOR_COLOR_INNER;
            default:
                return CardTheme.UNKNOWN_CONNECTOR_COLOR_INNER;
        }
    }

    public enum Type {
        PULSE,
        BOOLEAN,
        STRING,
        ANY,
        ENUM,
        UNKNOWN,
        FLOAT,
        INTEGER,
    }

    public ConnectorTypeInfo(ConnectorTypeInfo.Type type) {
        this._type = type;
    }

    public Type get_type() {
        return _type;
    }
}
