package com.programaker.bridge

import com.codigoparallevar.minicards.ConfigManager
import org.json.JSONObject

class ProgramakerBridgeConfiguration(
        val serviceName: String,
        val configManager: ConfigManager,
        val blocks: List<ProgramakerBridgeConfigurationBlock>
        // val is_public: boolean, // No reason for this use case
        // val registration: ???, // No reason for this use case
        // val allow_multiple_connections: boolean // No reason for this use case
        // val icon: ???, // Not supported yet // TODO: Add support
) {

    fun serialize(): String {
        var serializedBlocks = listOf<JSONObject>()
        if (blocks != null) {
            serializedBlocks = blocks.map { it.serialize() }
        }

        val config = JSONObject(hashMapOf(
                "service_name" to serviceName,
                "is_public" to false,
                "registration" to null,
                "allow_multiple_connections" to null,
                "icon" to null,
                "blocks" to serializedBlocks
        ) as Map<*, *>)

        val wrapper = JSONObject(hashMapOf(
                "type" to "CONFIGURATION",
                "value" to config
        ) as Map<*, *>)

        return wrapper.toString()
    }

    fun callFunction(functionName: String, arguments: List<*>) {
        for (block in blocks) {
            if (block.getFunctionName() == functionName) {
                return block.call(arguments)
            }
        }

        throw IllegalArgumentException("Bridge function (name=$functionName) not found")
    }
}